@@ -235,6 +235,28 @@ class CloudPods:
             log.error(f"服务器创建请求发生异常: {str(e)}", exc_info=True)
             return None
 
+    @enter_and_leave_function
+    def modify_src_check(self, server_id, src_ip_check="on", src_mac_check="on"):
+        log.info(f"Begin to request /servers/{server_id}/modify-src-check...")
+        res_data = {}
+        try:
+            modify_src_check_url = f"/servers/{server_id}/modify-src-check"
+            data = {
+                "server": {
+                    "src_ip_check": src_ip_check,
+                    "src_mac_check": src_mac_check
+                }
+            }
+            url = self.__compute_url + modify_src_check_url
+            res = self.__session.post(url=url, json=data, verify=False, timeout=600)
+            res_data = res.json()
+            log.info(f"Success to request /servers/{server_id}/modify-src-check: OK. response data is {res_data}")
+        except Exception as e:
+            log.error(f"Failed to request /servers/{server_id}/modify-src-check: Error. err msg is {str(e)}",
+                      exc_info=True)
+        finally:
+            return res_data
+
     @enter_and_leave_function
     def create_server_by_guest_image(
             self,
@@ -486,6 +508,7 @@ class CloudPods:
                     running_status_count += 1
                     if running_status_count > 5:
                         log.info(f"server_id: {server_id} running for 5 times check.")
+                        self.modify_src_check(server_id,"off","off")
                         return True
                     else:
                         log.warning(f"just {running_status_count} times check: server_id: {server_id} running status: {server_detail['server']['status']}")
@@ -713,18 +736,19 @@ class CloudPods:
 
 
 if __name__ == '__main__':
-    # cloudpods = CloudPods('https://10.30.18.1:30500/v3','admin','jSj@2008')
+    cloudpods = CloudPods('https://10.30.18.1:30500/v3','admin','jSj@2008')
     # server_ip = cloudpods.get_server_ip("e3b76ec7-c4f9-4065-8ce2-9d833b51368c")
     # print(server_ip)
     # cloudpods = CloudPods('https://10.240.30.110:30500/v3', 'admin', 'jSj@2008')
-    cloudpods = CloudPods('https://10.20.40.101:30500/v3', 'admin', 'jSj@2008')
+    # cloudpods = CloudPods('https://10.20.40.101:30500/v3', 'admin', 'jSj@2008')
     # rs=cloudpods.wait_for_server_is_deleted("dddc5d9a-6bf5-4e37-860b-ec485a5a6823")
     # print(rs)
     # rs=cloudpods.get_baremetal_hosts()
     # for elem in rs:
     #     if elem["id"]=="5d6dfb67-db25-43d2-8057-116769fb3abf":
     #         print(elem)
-    rs = cloudpods.get_can_deploy_server_host_num("x86_64","bios")
+    # rs = cloudpods.get_can_deploy_server_host_num("x86_64","bios")
+    rs = cloudpods.modify_src_check("6fdbaa06-191f-4103-8571-fd65281d3b70","off","off")
     print(rs)
     # print(len(rs))
     # print(rs[0])
